<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis03000DapiMgFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis03000DapiMgService
{
    protected $environment;
    protected $dapiMgFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis03000DapiMgFactory $dapiMgFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->dapiMgFactory        = $dapiMgFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação DAPI-MG
     */
    private function createFileDapiMg($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];
        $dapiMgData = $this->dapiMgFactory->getDapiMgData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($dapiMgData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $dapiMgData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação DAPI-MG
     */
    public function exportarDapiMg($row) {
        // Valida os parâmetros associados.
        $this->validateDapiMg($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);

        // Monta o array com os parametros para chamar a procedure
        $params = [
            'CDEMPRESA'         => $row['CDEMPRESA'],
            'CDIMPOSTO'         => '00',
            'CDINSCESTA'        => $row['CDINSCESTA'],
            'DTINICIAL'         => $row['DTINICIAL'],
            'DTFINAL'           => $row['DTFINAL'],
            'LIVROMAG'          => $row['CDLIVROMAG'],
            'CDDESMEMCAE'       => $row['CDDESMEMCAE'],
            'CDDESMEMCNAEF'     => $row['CDDESMEMCNAEF'],
            'CDREGESPRECOLHI'   => $row['CDREGESPRECOLHI'],
            'CDOPTFUND'         => $row['CDOPTFUND'],
            'CDMOVCAFE'         => $row['CDMOVCAFE'],
            'CDDAPIMOV'         => $row['CDDAPIMOV'],
            'CDDAPISUB'         => $row['CDDAPISUB'],
            'CDINDENCERR'       => $row['CDINDENCERR'],
            'DTLIMPAG'          => $row['DTLIMPAG'],
            'CDREGIMREC'        => $row['CDREGIMREC'],
            'CDTERMACEIT'       => $row['CDTERMACEIT'],
            "NRSEQARQMAG"       => $row["NRSEQARQMAG"],
        ];

        // Chama a procedure de exportação
        $this->dapiMgFactory->callDapiMgProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileDapiMg($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->dapiMgFactory->deleteDapiMgData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->dapiMgFactory->deleteDapiMgData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o DAPI-MG
     */
    private function validateDapiMg($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se campo 'Desmembramento CAE' possui algum vlr informado
            if(empty($row['CDDESMEMCAE'])){
                throw new \Exception('Desmembramento CAE deve ser informado');
            }
            // Verifica se campo 'Desmembramento CNAE-F' possui algum vlr informado
            if(empty($row['CDDESMEMCNAEF'])){
                throw new \Exception('Desmembramento CNAE-F deve ser informado');
            }
            // Verifica se campo 'Regime Esp. de Recolhimento' possui algum vlr informado
            if(empty($row['CDREGESPRECOLHI'])){
                throw new \Exception('Regime Esp. de Recolhimento deve ser informado');
            }
            // Verifica se campo 'Optante pelo FUNDESE' possui algum vlr informado
            if(empty($row['CDOPTFUND'])){
                throw new \Exception('Optante pelo FUNDESE deve ser informado');
            }
            // Verifica se campo 'Movimento de Cafe' possui algum vlr informado
            if(empty($row['CDMOVCAFE'])){
                throw new \Exception('Movimento de Cafe deve ser informado');
            }
            // Verifica se campo 'DAPI com Movimento' possui algum vlr informado
            if(empty($row['CDDAPIMOV'])){
                throw new \Exception('DAPI com Movimento deve ser informado');
            }
            // Verifica se campo 'DAPI para Substituição' possui algum vlr informado
            if(empty($row['CDDAPISUB'])){
                throw new \Exception('DAPI para Substituição deve ser informado');
            }
            // Verifica se campo 'Indicador de Encerramento' possui algum vlr informado
            if(empty($row['CDINDENCERR'])){
                throw new \Exception('Indicador de Encerramento deve ser informado');
            }
            // Verifica se campo 'Limite de Pagamento' possui alguma data informada
            if(empty($row['DTLIMPAG'])){
                throw new \Exception('Limite de Pagamento deve ser informado');
            }
            // Verifica se campo 'Regime de Recolhimento' possui algum vlr informado
            if(empty($row['CDREGIMREC'])){
                throw new \Exception('Regime de Recolhimento deve ser informado');
            }
            // Verifica se campo 'Termo de aceite' possui algum vlr informado
            if(empty($row['CDTERMACEIT'])){
                throw new \Exception('Termo de aceite deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            //$nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            //$row['NRORG'] = $nrorg;
    
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTREFINI'])){
                throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Desmembramento CAE' possui algum vlr informado
            if(empty($row['CDDESMEMCAE'])){
                throw new \Exception('Desmembramento CAE deve ser informado');
            }
            // Verifica se o campo 'Desmembramento CNAE-F' possui algum vlr informado
            if(empty($row['CDDESMEMCNAEF'])){
                throw new \Exception('Desmembramento CNAE-F deve ser informado');
            }
            // Verifica se o campo 'Regime Esp. de Recolhimento' possui algum vlr informado
            if(empty($row['CDREGESPRECOLHI'])){
                throw new \Exception('Regime Esp. de Recolhimento deve ser informado');
            }
            // Verifica se o campo 'Optante pelo FUNDESE' possui algum vlr informado
            if(empty($row['CDOPTFUND'])){
                throw new \Exception('Optante pelo FUNDESE deve ser informado');
            }
            // Verifica se o campo 'Movimento de Cafe' possui algum vlr informado
            if(empty($row['CDMOVCAFE'])){
                throw new \Exception('Movimento de Cafe deve ser informada');
            }
            // Verifica se o campo 'DAPI com Movimento' possui algum vlr informado
            if(empty($row['CDDAPIMOV'])){
                throw new \Exception('DAPI com Movimento deve ser informada');
            }
            // Verifica se o campo 'DAPI para Substituição' possui algum vlr informado
            if(empty($row['CDDAPISUB'])){
                throw new \Exception('DAPI para Substituição deve ser informada');
            }
            // Verifica se o campo 'Indicador de Encerramento' possui algum vlr informado
            if(empty($row['CDINDENCERR'])){
                throw new \Exception('Indicador de Encerramento deve ser informada');
            }
            // Verifica se o campo 'Limite de Pagamento' possui algum vlr informado
            if(empty($row['DTLIMPAG'])){
                throw new \Exception('Limite de Pagamento deve ser informada');
            }
            // Verifica se o campo 'Regime de Recolhimento' possui algum vlr informado
            if(empty($row['CDREGIMREC'])){
                throw new \Exception('Regime de Recolhimento deve ser informada');
            }
            // Verifica se o campo 'Termo de aceite' possui algum vlr informado
            if(empty($row['CDTERMACEIT'])){
                throw new \Exception('Termo de aceite deve ser informada');
            }
            
        
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $datas = $this->obrigacoesService->getFirstAndLastDays($row['DTREFINI']);
            $row['DTINICIAL'] = $datas['DTINICIAL'];
            $row['DTFINAL']= $datas['DTFINAL'];
            $row['NRORG'] = $nrorg;
        
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->dapiMgFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS03000';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;
            
            //var_dump($row);
            //throw new \Exception('ioioioioioi');
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->dapiMgFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->dapiMgFactory->insertAgendamento($row);
            } else {
                $this->dapiMgFactory->updateAgendamento($row);
                
                 $arquivos = $this->dapiMgFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dapiMgFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->dapiMgFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->dapiMgFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->dapiMgFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - DAPI (Minas Gerais)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                //Conferir caminho do diretorio do xampp
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                //$dirphp = str_replace('/','\',$DIRPHP);
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoDapiMg';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->dapiMgFactory->findAgendamentoExec($row)[0];
            
            $findParamDeclAcess = $this->dapiMgFactory->findParamDeclAcess($agendamento);
            
            $agendamento['MOVOPPR'] = isset($findParamDeclAcess['MOVOPPR']) ? $findParamDeclAcess['MOVOPPR'] : null;
            $agendamento['MOVST']   = isset($findParamDeclAcess['MOVST']) ? $findParamDeclAcess['MOVST'] : null;
            $agendamento['MOVICMS'] = isset($findParamDeclAcess['MOVICMS']) ? $findParamDeclAcess['MOVICMS'] : null;
            $agendamento['MOVALC']  = isset($findParamDeclAcess['MOVALC']) ? $findParamDeclAcess['MOVALC'] : null;
            $agendamento['VERSAO']  = isset($findParamDeclAcess['VERSAO']) ? $findParamDeclAcess['VERSAO'] : null;
            $agendamento['RETIFIC'] = isset($findParamDeclAcess['RETIFIC']) ? $findParamDeclAcess['RETIFIC'] : null;
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->dapiMgFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->dapiMgFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'DAPI (Minas Gerais) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->dapiMgFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de DAPI (Minas Gerais) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de DAPI (Minas Gerais):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                       $this->geraArquivo = true;
                            
                        $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                        $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                        
                        if($agendamento['IDPERIAGEN'] == '0'){
                            $dtinicial = $agendamento["DTINICIAL"];
                            $dtfinal = $agendamento["DTFINAL"];
                        } 
                        else if($agendamento['IDPERIAGEN'] == '1'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        } 
                        else if($agendamento['IDPERIAGEN'] == '2'){
                            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                            $dtinicial = $dtinicial->format("d/m/Y");
                            $dtfinal = $dtfinal->format("d/m/Y");
                        }
                
                        $agendamento["DTINICIAL"] = $dtinicial;
                        $agendamento["DTFINAL"] = $dtfinal;
                        
                        $agendamento['CDINSCESTA'] = $inscEsta;
                        $agendamento["NMARQUIVO"] = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarDapiMg($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->dapiMgFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->dapiMgFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->dapiMgFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->dapiMgFactory->getAgendamentoInsert($row)[0];

            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);

                $getConfigSMTP = $this->dapiMgFactory->getConfiguraSMTP($agendamento)[0];
             
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->dapiMgFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->dapiMgFactory->deleteAgendamentoArquivo($arquivo);
                    $this->dapiMgFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->dapiMgFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
                
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
}