<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Factories\Fis11000CompraLegalBaFactory;
use Teknisa\FIS\Modules\Acessorias\Services\Fis91000ObrigacoesAcessoriasService;
use Teknisa\FIS\Modules\Acessorias\Services\Agendamento;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Libs\Util\NewCode;
use \Teknisa\Libs\Util\Libraries\PHPMailer;

class Fis11000CompraLegalBaService
{
    protected $environment;
    protected $compraLegalBaFactory;
    protected $obrigacoesService;
    
    public $mensagemBody = '';
    public $mensagemBodySucess = '';
    public $mensagemError = '';
    public $mensagemErrorBody = '';
    public $geraArquivo = '';

    public function __construct(Environment $environment, Fis11000CompraLegalBaFactory $compraLegalBaFactory, Fis91000ObrigacoesAcessoriasService $obrigacoesService,
                                    NewCode $newCode, Agendamento $agendamento )
    {
        $this->environment          = $environment;
        $this->compraLegalBaFactory = $compraLegalBaFactory;
        $this->obrigacoesService    = $obrigacoesService;
        $this->newCode              = $newCode;
        $this->agendamento          = $agendamento;
    }

    /**
     * Função para criar o arquivo da exportação Compra LEGAL - BA
     */
    private function createFileCompraLegalBa($row) {
        // Cria os parâmetros para buscar os dados gerados na procedure.
        $params = [
            'NRORG' => $row['NRORG'],
            'NRSEQARQMAG' => $row['NRSEQARQMAG'],
        ];

        $compraLegalBaData = $this->compraLegalBaFactory->getCompraLegalBaData($params);

        if(isset($row['NRAGENDAMENTO']) && empty($compraLegalBaData)){
            $this->mensagemError = '<br />'."Não há dados a serem exibidos.";
            return $fileName = false;
        }
        // Chama a função para a criação do arquivo.
        $fileName = $this->obrigacoesService->createFileExportacao($row['NMARQUIVO'], $compraLegalBaData, 'DSREGARQMAG');

        // Retorna o nome do arquivo exportado.
        return $fileName;
    }

    /**
     * Função para a exportação Compra LEGAL (Bahia)
     */
    public function exportarCompraLegalBa($row) {
        // Valida os parâmetros associados.
        $this->validateCompraLegalBa($row);
        
        if(isset($row['NRAGENDAMENTO']) && $this->geraArquivo == false){
            return false;
        }
        // Gera o código sequencial do arquivo magnético através do NOVOCODIGO.
        $row['NRSEQARQMAG'] = $this->obrigacoesService->getNextNrseqarqmag($row['NRORG']);
        // Monta o array com os parametros para chamar a procedure
        $params = [
            'NRLISTA'       => $row['NRLISTA'],
            'CDEMPRESA'     => $row['CDEMPRESA'],
            'CDIMPOSTO'     => $row['CDIMPOSTO'],
            'CDINSCESTA'    => $row['CDINSCESTA'],
            'DTINICIAL'     => $row['DTINICIAL'],
            'DTFINAL'       => $row['DTFINAL'],
            'NRSEQARQMAG'   => $row['NRSEQARQMAG'],
        ];
        
        // Chama a procedure de exportação
        $this->compraLegalBaFactory->callCompraLegalBaProcedure($params);

        /**
         * Foi evitado utilizar um bloco finally devido à possível
         * incompativilidade com a versão do PHP
         */
        try
        {
            // Seta os parametros paar a exclusão dos dados temporários
            $params = [
                'NRORG' => $row['NRORG'],
                'NRSEQARQMAG' => $row['NRSEQARQMAG'],
            ];
            // Chama a função para gerar o arquivo texto
            $fileName = $this->createFileCompraLegalBa($row);

            // Exclui os dados temporários da exportação no banco de dados
            $this->compraLegalBaFactory->deleteCompraLegalBaData($params);

            // Retorna o nome do arquivo com suas possíveis modificações
            return $fileName;
        }
        catch(\Exception $e)
        {
            // Exclui os dados temporários da exportaçao no banco de dados
            $this->compraLegalBaFactory->deleteCompraLegalBaData($params);
            throw $e;
        }

    }

    /**
     * Função para validação dos dados informados para o Compra LEGAL - BA
     */
    private function validateCompraLegalBa($row) {
        if (isset($row['NRAGENDAMENTO'])){
            
            $this->mensagemError = '';
            
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDIMPOSTO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Empresa deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTINICIAL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['DTFINAL'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Referência deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Referência deve ser informada');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Nome do Arquivo deve ser informado.';
                $this->geraArquivo = false;
                //throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                $this->mensagemError = $this->mensagemError.'<br />'.'Incrição Estadual deve ser informada.';
                $this->geraArquivo = false;
                //throw new \Exception('Incrição Estadual deve ser informado');
            }
            // Verifica se o campo 'Gera Registros de Balanço Patrimonial' possui algum vlr informado
            
            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = array('00');
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
    
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                $this->mensagemError = $this->mensagemError.'<br />'.'Todos os mapas devem estar bloquados para a geração do arquivo.';
                $this->geraArquivo = false;
                //throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
        else {
            // Verifica se o campo 'Empresa' possui algum vlr informado
            if(empty($row['CDEMPRESA'])){
                throw new \Exception('Empresa deve ser informada');
            }
            // Verifica se o campo 'Referência' possui algum vlr informado
            if(empty($row['CDIMPOSTO'])){
                throw new \Exception('Imposto deve ser informado');
            }
            // Verifica se o campo 'Nome do Arquivo' possui algum vlr informado
            if(empty($row['DTINICIAL'])){
                throw new \Exception('Data deve ser informada');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['DTFINAL'])){
                throw new \Exception('Data deve ser informada');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['NMARQUIVO'])){
                throw new \Exception('Nome do Arquivo deve ser informado');
            }
            // Verifica se o campo 'Inscrição Estadual' possui algum vlr informado
            if(empty($row['CDINSCESTA'])){
                throw new \Exception('Inscrição Estadual deve ser informado');
            }
            
            /**
             * Busca e atribui os valores de NRORG e datas inicial e final do mẽs
             * à variável row
             */
            $nrorg = $this->environment->getNrorg();
            $row['NRORG']       = $nrorg;

            // Seta o imposto a ser validado no mapa de apuração.
            $impostos = $row['CDIMPOSTO'];
            // Valida o mapa de apuração
            $mapaApuracIsValid = $this->obrigacoesService->mapaApuracIsValid($row, $impostos);
        
            // Verifica se o mapa está invalido, lançando um erro em caso positivo.
            if(!$mapaApuracIsValid){
                throw new \Exception('Todos os mapas devem estar bloquados para a geração do arquivo.');
            }
        }
    }
    
    
    public function findAgendamento() {
        // Busca os parâmetros conforme empresa e nrorg.
        $agendamento = $this->compraLegalBaFactory->findAgendamento();

        return $agendamento;
    }
    
    public function saveAgendamento($row) {
        try {
            
            $row['CDTELA'] = 'FIS11000';
            
            $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData($row['DTREFINI']));
            $dtinicial = $dtinicial->format("d/m/Y");
            $dtfinal = $dtfinal->format("d/m/Y");
    
            $row["DTINICIAL"] = $dtinicial;
            $row["DTFINAL"] = $dtfinal;

            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $row["NRAGENDAMENTO"] = $this->newCode->getCodeByTableName('NRAGENDAMENTO', $row["NRORG"], 1, 10);
            }
            
            if($row['CDINSCESTA'] == 'T'){
                $arrayInscEsta = $this->compraLegalBaFactory->getInscEsta($row);
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value['CDINSCESTA'].'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } else if(is_array($row['CDINSCESTA']) == true){
                $arrayInscEsta = $row['CDINSCESTA'];
                $cdinscesta = '_';
                
                foreach($arrayInscEsta as $value){
                    $cdinscesta = $cdinscesta.$value.'_';
                }
                
                $row['CDINSCESTA'] = $cdinscesta;
            } 
            
            if(isset($row['__is_new']) && $row['__is_new'] == true){
                $this->compraLegalBaFactory->insertAgendamento($row);
            } else {
                $this->compraLegalBaFactory->updateAgendamento($row);
                
                 $arquivos = $this->compraLegalBaFactory->getAgendamentoArquivo($row);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->compraLegalBaFactory->deleteAgendamentoArquivo($arquivo);
                }
                
                $idstatus = 'P';
                $this->compraLegalBaFactory->updateAgendamentoIdStatus($row, $idstatus);
                
            }
            
            $agendamento = $this->compraLegalBaFactory->getAgendamentoInsert($row);
            
            if($agendamento){
                
                $agendamento['NRORG'] = $row['NRORG'];
                $getConfigSMTP = $this->compraLegalBaFactory->getConfiguraSMTP($agendamento)[0];
                if(isset($row['__is_new']) && $row['__is_new'] == true){
                    $nomeJob = $row['CDTELA'].'_'.$row['NRAGENDAMENTO'];
                } else {
                    $nomeJob = $row['CDTELA'].'_'.str_pad($row['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                }
                $dataContabAuto = $row['DTAGENDAMENTO'];
                $sequencialJob = $row['NRAGENDAMENTO'];
                $nrorg = $row['NRORG'];
                $descricao = $row['CDTELA'].' - Compra LEGAL (Bahia)'.'. Exportação das declarações Acessórias de forma automática na data de '.$row['DTAGENDAMENTO'];
                $arqCallService = $getConfigSMTP['CALLSERVPATH'];//'C:\Teknisa\CallService.php';
                $dirphp = $getConfigSMTP['DIRPHP'];//'C:/xampp/php';
                $jenkinsPath = $getConfigSMTP['JENKINSPATH'];//'http://192.168.120.132:8080/';
                $execPath = '/execAgendamentoCompraLegalBa';
                $periodicidade = $row['IDPERIAGEN'];
                $jenkinsCreateItem = $getConfigSMTP['JENKCREATITEM'];
                $this->agendamento->criaJob($nomeJob, $dataContabAuto, $sequencialJob, $nrorg, $descricao, $arqCallService, $dirphp, $jenkinsPath, $execPath, $periodicidade, $jenkinsCreateItem);
                
            }
            
        } catch(\Exception $e) {
            //
            throw $e;
        }
    }
    
    public function execAgendamento($row){
        try{
            $agendamento = $this->compraLegalBaFactory->findAgendamentoExec($row)[0];
            
            if($agendamento){
                $this->mensagemBody = '';
                
                $agendamento["NRORG"] = $row['NRORG'];
                
                $agendamento["DTEXECAGEND"] = $agendamento["DTATUAL"];
                
                $agendamento["DTREFINI"] = explode(' ', $agendamento["DTREFINI"])[0];
                
                //Necessário Fazer a verificação
                
                $agendamento['CDINSCESTAARRAY'] = $agendamento['CDINSCESTA'];
                $arrayInscEsta = explode('_',$agendamento['CDINSCESTAARRAY']);
                
                $getConfigSMTP = $this->compraLegalBaFactory->getConfiguraSMTP($agendamento)[0];
                $getContatos = $this->compraLegalBaFactory->getContatos($agendamento);
                
                $mail = new PHPMailer;
                $mail->CharSet = 'UTF-8';
                $mail->isSMTP();                        // Set mailer to use SMTP
                $mail->isHTML();
                $mail->Host = $getConfigSMTP['SERVIDORSMTP'];       // Specify main and backup SMTP servers
                $mail->SMTPAuth = true;                 // Enable SMTP authentication
                $mail->Username = $getConfigSMTP['LOGINSMTP'];    // SMTP username
                $mail->Password = $getConfigSMTP['SENHASMTP'];    // SMTP password
                $mail->From = $getConfigSMTP['LOGINSMTP'];
                $mail->FromName = 'ERP Pebbian';
                $mail->Subject = 'Compra LEGAL (Bahia) de '.$agendamento['DTAGENDAMENTO'];
                // $mail->addAddress($cliente['DSEMAILCLIE']);
                // $mail->addAddress($vendedor['DSEMAILOPER']);
                
                foreach($getContatos as $contato){
                    $mail->addAddress($contato['EMAIL']);
                };
                
                $agendamento["NMEMPRESA"] = $this->compraLegalBaFactory->getNmEmpresa($agendamento)["NMEMPRESA"];
                        
                $this->mensagemBody = 'Caro cliente, '.'<br />'.'<br />';
                $this->mensagemBodySucess = 'Arquivo de Compra LEGAL (Bahia) gerado com Sucesso!'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                $this->mensagemErrorBody = 'Erro ao gerar o arquivo de Compra LEGAL (Bahia):'.'<br />'.'<br />'
                .'<br />'.'Empresa: '.$agendamento['CDEMPRESA'].' - '.$agendamento['NMEMPRESA'];
                
                
                $contErro = 0;
                $contSucess = 0;
                
                $dataName = str_replace('/', '', explode(' ', $agendamento["DTATUAL"])[0]);
                $horaName = str_replace(':', '', explode(' ', $agendamento["DTATUAL"])[1]);
                
                if($agendamento['IDPERIAGEN'] == '0'){
                    $dtinicial = $agendamento["DTINICIAL"];
                    $dtfinal = $agendamento["DTFINAL"];
                } 
                else if($agendamento['IDPERIAGEN'] == '1'){
                    $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                    $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["DTATUAL"])[0]));
                    $dtinicial = $dtinicial->format("d/m/Y");
                    $dtfinal = $dtfinal->format("d/m/Y");
                } 
                else if($agendamento['IDPERIAGEN'] == '2'){
                    $dtinicial  = DateUtil::getPrimeiroDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                    $dtfinal    = DateUtil::getUltimoDiaDoMes( $this->formataData(explode(' ', $agendamento["LAST_MONTH"])[0]));
                    $dtinicial = $dtinicial->format("d/m/Y");
                    $dtfinal = $dtfinal->format("d/m/Y");
                } 
        
                $agendamento["DTINICIAL"]   = $dtinicial;
                $agendamento["DTFINAL"]     = $dtfinal;
                
                $notasFiscais = $this->compraLegalBaFactory->findNotasFiscaisExec($agendamento);
                
                $agendamento["NRLISTA"] = $this->saveListaCompraLegalBa($notasFiscais);
                
                foreach( $arrayInscEsta as $inscEsta ){
                    if(isset($inscEsta) && $inscEsta != ''){
                        
                        $this->geraArquivo = true;
                            
                        $agendamento['CDINSCESTA']  = $inscEsta;
                        $agendamento["NMARQUIVO"]   = $agendamento['CDTELA'].$agendamento['NRAGENDAMENTO'].'_'.$inscEsta.'_'.$dataName.$horaName;
                          
                        $fileName = $this->exportarCompraLegalBa($agendamento);
                        
                        if($this->mensagemError == ''){
                            $this->mensagemBodySucess = $this->mensagemBodySucess
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA'];
                            ++$contSucess;
                            
                        } else {
                            $this->mensagemErrorBody = $this->mensagemErrorBody
                            .'<br />'.'Inscrição Estadual: '.$agendamento['CDINSCESTA']
                            .$this->mensagemError.'<br />'.'<br />';
                            ++$contErro;
                        }
                        
                        if($fileName){
                            $file = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName;
                            $agendamento["NMPATHARQ"] = $file ;
                            
                            $verifArq = $this->compraLegalBaFactory->verAgendamentoArquivo($agendamento);
                            
                            if(empty($verifArq)){
                                $agendamento["NRARQUIVO"] = $this->newCode->getCodeByTableName('NRARQUIVO', $agendamento["NRORG"], 1, 10);
                                $this->compraLegalBaFactory->insertAgendamentoArquivo($agendamento);
                            }
                        }
                
                    }
                }
                
                if(($contErro > 0) && ($contSucess > 0)){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'.'<br />'
                    .'---------------------------------------------------------------------'.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                } 
                else if($contErro > 0){
                    $mail->Body = $this->mensagemBody.'<br />'
                    .$this->mensagemErrorBody
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                else if($contSucess > 0){
                    $mail->Body = $this->mensagemBody.'<br />'.$this->mensagemBodySucess.'<br />'
                    .'<br />'.'Atenciosamente,'.'<br />'.'<br />'.'Equipe ERP Pebbian.';
                    $mail->send();
                }
                
                $idstatus = 'R';
                $this->compraLegalBaFactory->updateAgendamentoIdStatus($agendamento, $idstatus);
                
                $deletaLista['NRLISTA'] = $agendamento['NRLISTA'];
                
                $this->deleteListaCompraLegalBa($deletaLista);
                
            }
        
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAgendamento($row){
        try {    
            
            $agendamento = $this->compraLegalBaFactory->getAgendamentoInsert($row)[0];
            
            
            if($agendamento){
                $nomeJob = $agendamento['CDTELA'].'_'.str_pad($agendamento['NRAGENDAMENTO'], 10, "0", STR_PAD_LEFT);
                $getConfigSMTP = $this->compraLegalBaFactory->getConfiguraSMTP($agendamento)[0];
                
                $this->agendamento->apagaJob($nomeJob, null, $getConfigSMTP['JENKINSPATH'], $getConfigSMTP["CALLSERVPATH"]);
                
                $arquivos = $this->compraLegalBaFactory->getAgendamentoArquivo($agendamento);
                
                if($arquivos){
                    foreach($arquivos as $arquivo){
                        unlink($arquivo['NMPATHARQ']);
                    }
                    
                    $this->compraLegalBaFactory->deleteAgendamentoArquivo($arquivo);
                    $this->compraLegalBaFactory->deleteAgendamento($arquivo);
                    
                } else {
                    $this->compraLegalBaFactory->deleteAgendamento($agendamento);
                }
                
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
                
    }
    
    public function saveListaCompraLegalBa($rows){
        try {    
            
            $NRLISTA = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab());
            
            foreach($rows as $row){
                $row['CDLISTA'] = $row['CDFILIAL'].$row['NRLANCTONF'];
                $row['NRLISTA'] = $NRLISTA;
                $this->compraLegalBaFactory->saveListaCompraLegalBa($row);
            }
            
            return $row['NRLISTA'];
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteListaCompraLegalBa($row){
        try {    
            
            $this->compraLegalBaFactory->deleteListaCompraLegalBa($row);
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
 
    private function formataData($data) {
        if (!$data) {
            return null;
        }

        // Verifica se está com o formato de data-hora.
        if (strlen($data) == 19) {
            $data = DateUtil::truncateString($data);
        }
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }
    
}