<?php

namespace Teknisa\FIS\Modules\Guias\Controllers;

use Teknisa\FIS\Modules\Guias\Services\Fis00200DocumentoDeArrecadacaoService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;

class Fis00200DocumentoDeArrecadacaoController extends \Teknisa\FIS\Controllers\TeknisaCrud{
    protected $service;
    protected $crudService;
    protected $dataSourceName;
    protected $dataSourceNameToSave  = false;
    protected $parameterBag;
    protected $parameterBagColumns = array();

    public function __construct($crudService, ParameterBag $parameterBag, Fis00200DocumentoDeArrecadacaoService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }

    public function validaImpostosRelacionados (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $validation = $this->service->validaImpostosRelacionados($row['CDIMPOSTONFE']);
            $response->addDataSet(new DataSet("validation", $validation));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }  
    
    public function valoresDefaultPagamento (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row   = $request->getRow();
            $resul = $this->service->valoresDefaultPagamento($row['CDIMPOSTO'], $row['CDEMPRESA'], $row['IDTIPOEMISSAO']);
            $response->addDataSet(new DataSet("dadosPagamento", $resul));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }  
    
    public function salvarEdicaoGuia (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $res = $this->service->salvarEdicaoGuia($row);
            $response->addDataSet(new DataSet("nrseqdocarrecad", array($res)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }  
   
    public function preparaPagamento (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $res = $this->service->preparaPagamento($row);
            
            $response->addDataSet(new DataSet("response", $res));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }  
    
    public function cancelaDadosFinanceiro (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $res = $this->service->cancelaDadosFinanceiro($row);
            
            $response->addDataSet(new DataSet("response", $res));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function emitirGuia(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $resul = $this->service->emitirGuia($row);
            $response->addDataSet(new DataSet("relatorio", array($resul)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function emitirGnreOnline(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataSet()->getRows();
            $resul = $this->service->emitirGnreOnline($dataset);
            
            $response->addMessage(new DTO\Response\Message($resul));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function consultarLoteGnreOnline(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $resul = $this->service->consultarLoteGnreOnline($rows);
            $response->addDataSet(new DataSet("consulta", $resul));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function emitirGnreTxt(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            
            $arquivo = $this->service->getArquivoGuiaGnreTxt( $rows );
            
            $response->addDataSet( new DataSet( "arquivo", array( $arquivo ) ) );
        } catch( \Exception $e ) {
            $response->setError( new Error( $e->getMessage(), $e->getCode() ) );
        }
    }
    
    public function transmitirLoteRj(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataSet()->getRows();
            $resul = $this->service->transmitirLoteRj($dataset);
            $response->addMessage(new DTO\Response\Message($resul));
           
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function consultarLoteRj(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $resul = $this->service->consultarLoteRj($rows);
            $response->addDataSet(new DataSet("consulta", $resul));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 

    public function transmitirLoteEs(DTO\Request $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataSet()->getRows();
            $resul = $this->service->transmitirLoteEs($dataset);
            $response->addMessage(new DTO\Response\Message($resul));
           
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}